Welcome to -rbf |
===============================

This is a package for Robot Framework that includes test libraries to support test automation for various components including REST APIs, Web, FTP, DB, Desktop and Mainframe applications  

Installation Instructions
-------------------------

The preferred method of installation is to use pip:

    $ pip install --upgrade rbf





